==> Software-License-CCpack-1.0.tar.gz: Software-License-CCpack-1.0/lib/Software/License/CC_PDM_1_0.pm <==
use strict;
use warnings;
package Software::License::CC_PDM_1_0;
{
  $Software::License::CC_PDM_1_0::VERSION = '1.0';
}
use base 'Software::License';
# ABSTRACT: Creative Commons Public Domain Mark 1.0

sub name { 'Creative Commons Public Domain Mark 1.0' }
sub url  { 'http://creativecommons.org/publicdomain/mark/1.0/' }

sub version    { '1.0' }
sub meta_name  { 'unrestricted' }

1;


=pod

=head1 NAME

Software::License::CC_PDM_1_0 - Creative Commons Public Domain Mark 1.0

=head1 VERSION

version 1.0

=head1 AUTHOR

Brendan Byrd <BBYRD@CPAN.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2012 by Brendan Byrd.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 3, June 2007

=cut


__DATA__
__LICENSE__
Public Domain Mark 1.0

No Copyright

* This work has been identified as being free of known restrictions under
  copyright law, including all related and neighboring rights.

  You can copy, modify, distribute and perform the work, even for commercial
  purposes, all without asking permission. See Other Information below.

* Other Information

  o The work may not be free of known copyright restrictions in all
    jurisdictions.

  o Persons may have other rights in or related to the work, such as patent
    or trademark rights, and others may have rights in how the work is used,
    such as publicity or privacy rights.

  o In some jurisdictions moral rights of the author may persist beyond the
    term of copyright. These rights may include the right to be identified as
    the author and the right to object to derogatory treatments.

  o Unless expressly stated otherwise, the person who identified the work
    makes no warranties about the work, and disclaims liability for all uses
    of the work, to the fullest extent permitted by applicable law.

  o When using or citing the work, you should not imply endorsement by the
    author or the person who identified the work.

==> Software-License-CCpack-1.01.tar.gz: Software-License-CCpack-1.01/lib/Software/License/CC_PDM_1_0.pm <==
use strict;
use warnings;
package Software::License::CC_PDM_1_0;
use base 'Software::License';
# ABSTRACT: Creative Commons Public Domain Mark 1.0

sub name { 'Creative Commons Public Domain Mark 1.0' }
sub url  { 'http://creativecommons.org/publicdomain/mark/1.0/' }

sub version    { '1.0' }
sub meta_name  { 'unrestricted' }

1;

=pod

=encoding utf-8

=head1 NAME

Software::License::CC_PDM_1_0 - Creative Commons Public Domain Mark 1.0

=head1 AVAILABILITY

The project homepage is L<https://github.com/SineSwiper/Software-License-CCpack/wiki>.

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see L<https://metacpan.org/module/Software::License::CCpack/>.

=head1 AUTHOR

Brendan Byrd <BBYRD@CPAN.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2013 by Brendan Byrd.

This is free software, licensed under:

  The GNU Lesser General Public License, Version 3, June 2007

=cut

__DATA__
__LICENSE__
Public Domain Mark 1.0

No Copyright

* This work has been identified as being free of known restrictions under
  copyright law, including all related and neighboring rights.

  You can copy, modify, distribute and perform the work, even for commercial
  purposes, all without asking permission. See Other Information below.

* Other Information

  o The work may not be free of known copyright restrictions in all
    jurisdictions.

  o Persons may have other rights in or related to the work, such as patent
    or trademark rights, and others may have rights in how the work is used,
    such as publicity or privacy rights.

  o In some jurisdictions moral rights of the author may persist beyond the
    term of copyright. These rights may include the right to be identified as
    the author and the right to object to derogatory treatments.

  o Unless expressly stated otherwise, the person who identified the work
    makes no warranties about the work, and disclaims liability for all uses
    of the work, to the fullest extent permitted by applicable law.

  o When using or citing the work, you should not imply endorsement by the
    author or the person who identified the work.
